{ config, pkgs, lib, inputs, nixpkgs-nixos-unstable-and-unfree, ... }:
{
  imports =
    [
      ./common-hardware.nix
      ./common-services.nix
      ./security.nix
      ./syncthing.nix
    ];

  security.allowUserNamespaces = true;

  environment.enableDebugInfo = true;

  environment.systemPackages = with pkgs; [
    wget
    git
    gnupg
    curl
    tmux
    htop
    atop
    home-manager
    pciutils
    powertop
    fd
    dnsutils
    usbutils
    nixpkgs-nixos-unstable-and-unfree.veracrypt
  ];

  i18n.defaultLocale = "en_GB.UTF-8";

  users.users.cyryl = {
    isNormalUser = true;
    extraGroups = [ "wheel" "networkmanager" "video" "scanner" "lp" "docker" "vboxusers" "adbusers" "libvirtd" "dialout" "wireshark" ];
    shell = pkgs.zsh;
  };

  networking.nameservers = [ "91.239.100.100" "89.233.43.71" "1.1.1.1" "8.8.8.8" ];

  networking.hosts = {
    "10.11.99.1" = [ "remarkable" ];
  };

  programs.light.enable = true;
  programs.adb.enable = true;
  programs.wireshark.enable = true;

  virtualisation.docker = {
    enable = true;
    autoPrune.enable = true;
  };

  fonts.fontconfig.enable = true;
  fonts.fonts = with pkgs; [ powerline-fonts weather-icons material-icons source-code-pro fira-code noto-fonts-emoji emojione iosevka font-awesome nerdfonts ];

  nix = {
    autoOptimiseStore = true;
    gc.automatic = true;
    optimise.automatic = true;
    package = pkgs.nixUnstable;
    extraOptions = ''
      experimental-features = nix-command flakes
    '';
  };

  system = {
    stateVersion = "20.03";
  };
}
